##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""ustr unit tests.
"""

import unittest

from zope.documenttemplate.ustr import ustr


class force_str:
    # A class whose string representation is not always a plain string:
    def __init__(self,s):
        self.s = s
    def __str__(self):
        return self.s


class Foo(str):

    pass


class Bar(str):

    pass


class UnicodeTests(unittest.TestCase):

    def testPlain(self):
        a = ustr('hello')
        assert a=='hello', repr(a)
        a = ustr(force_str('hello'))
        assert a=='hello', repr(a)
        a = ustr(chr(200))
        assert a==chr(200), repr(a)
        a = ustr(force_str(chr(200)))
        assert a==chr(200), repr(a)
        a = ustr(22)
        assert a=='22', repr(a)
        a = ustr([1,2,3])
        assert a=='[1, 2, 3]', repr(a)

    def testUnicode(self):
        a = ustr('hello')
        assert a=='hello', repr(a)
        a = ustr(force_str('hello'))
        assert a=='hello', repr(a)
        a = ustr(chr(200))
        assert a==chr(200), repr(a)
        a = ustr(force_str(chr(200)))
        assert a==chr(200), repr(a)

    def testExceptions(self):
        a = ustr(ValueError(chr(200)))
        assert a==chr(200), repr(a)

    def testCustomStrings(self):
        a = ustr(Foo('foo'))
        self.assertEqual(type(a), Foo)
        a = ustr(Bar('bar'))
        self.assertEqual(type(a), Bar)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest( unittest.makeSuite( UnicodeTests ) )
    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
